@@ -92,6 +92,8 @@ QStringList CatalogManager::_toBeSearched;
 CatalogManager::CatalogManager(QString configFile )
                  :KMainWindow(0,0)
 {
+   if ( configFile.isEmpty() )
+	configFile = KBabel::ProjectManager::defaultProjectName();
    _configFile = configFile;
 
    init();
@@ -126,8 +128,8 @@ void CatalogManager::init()
    {
 	KMessageBox::error( this, i18n("Cannot open project file\n%1").arg(_configFile)
 	    , i18n("Project File Error"));
-	    
-	_project = KBabel::ProjectManager::open(KBABEL_DEFAULTPROJECT);
+
+	_project = KBabel::ProjectManager::open(KBabel::ProjectManager::defaultProjectName());
    }
    
    connect( _project, SIGNAL (signalCatManSettingsChanged())
@@ -156,7 +158,7 @@ void CatalogManager::init()
            ,this,SLOT(openFile(QString,QString,int)));
    connect(_catalogManager, SIGNAL(selectedChanged(uint)),
            this, SLOT(selectedChanged(uint)));
-	   
+
    KWin::setIcons(winId(),BarIcon("catalogmanager",32)
            ,SmallIcon("catalogmanager"));
 
@@ -337,7 +339,8 @@ void CatalogManager::setupActions()
    action = new KAction(i18n("C&lose"), "fileclose"
            , this, SLOT(projectClose()),actionCollection()
            ,"project_close");
-   action->setEnabled (_project->filename() != KBABEL_DEFAULTPROJECT);
+
+   action->setEnabled (_project->filename() != KBabel::ProjectManager::defaultProjectName() );
 
    action = new KAction(i18n("&Configure..."), "configure"
            , this, SLOT(projectConfigure()),actionCollection()
@@ -657,7 +660,7 @@ void CatalogManager::openFile(QString filename, QString package)
 	kapp->updateRemoteUserTimestamp ("kbabel");
 
         if( !client->send("kbabel","KBabelIFace", callfunc, data) )
-            KMessageBox::error(this, i18n("Can not send a message to KBabel.\n"
+            KMessageBox::error(this, i18n("Cannot send a message to KBabel.\n"
                                           "Please check your installation of KDE."));
     }
 }
@@ -690,7 +693,7 @@ void CatalogManager::openFile(QString filename, QString package, int msgid)
 	kapp->updateRemoteUserTimestamp ("kbabel");
 
         if( !client->send("kbabel","KBabelIFace", callfunc, data) )
-            KMessageBox::error(this, i18n("Can not send a message to KBabel.\n"
+            KMessageBox::error(this, i18n("Cannot send a message to KBabel.\n"
                                           "Please check your installation of KDE."));
     }
 }
@@ -721,7 +724,7 @@ void CatalogManager::openFileInNewWindow(QString filename, QString package)
 	kapp->updateRemoteUserTimestamp ("kbabel");
 
         if( !client->send("kbabel","KBabelIFace", callfunc, data) )
-            KMessageBox::error(this, i18n("Can not send a message to KBabel.\n"
+            KMessageBox::error(this, i18n("Cannot send a message to KBabel.\n"
                                           "Please check your installation of KDE."));
     }
 }
@@ -751,7 +754,7 @@ void CatalogManager::openTemplate(QString openFilename,QString saveFilename,QStr
 	kapp->updateRemoteUserTimestamp ("kbabel");
 
         if( !client->send("kbabel","KBabelIFace", callfunc, data) )
-            KMessageBox::error(this, i18n("Can not send a message to KBabel.\n"
+            KMessageBox::error(this, i18n("Cannot send a message to KBabel.\n"
                                           "Please check your installation of KDE."));
     }
 }
@@ -781,7 +784,7 @@ void CatalogManager::openTemplateInNewWindow(QString openFilename,QString saveFi
 	kapp->updateRemoteUserTimestamp ("kbabel");
 
         if( !client->send("kbabel","KBabelIFace", callfunc, data) )
-            KMessageBox::error(this, i18n("Can not send a message to KBabel.\n"
+            KMessageBox::error(this, i18n("Cannot send a message to KBabel.\n"
                                           "Please check your installation of KDE."));
     }
 }
@@ -801,7 +804,7 @@ void CatalogManager::spellcheck()
 	kapp->updateRemoteUserTimestamp ("kbabel");
 
         if( !client->send("kbabel","KBabelIFace", "spellcheck(QStringList)", data) )
-            KMessageBox::error(this, i18n("Can not send a message to KBabel.\n"
+            KMessageBox::error(this, i18n("Cannot send a message to KBabel.\n"
                                           "Please check your installation of KDE."));
     }
 }
@@ -821,7 +824,7 @@ void CatalogManager::markedSpellcheck()
 	kapp->updateRemoteUserTimestamp ("kbabel");
 
         if( !client->send("kbabel","KBabelIFace", "spellcheck(QStringList)", data) )
-            KMessageBox::error(this, i18n("Can not send a message to KBabel.\n"
+            KMessageBox::error(this, i18n("Cannot send a message to KBabel.\n"
                                           "Please check your installation of KDE."));
     }
 }
@@ -955,6 +958,7 @@ void CatalogManager::find()
         {
             if( startKBabel() )
             {
+                QCString funcCall("findInFile(QCString,QCString,QString,int,int,int,int,int,int,int,int,int,int)");
                 DCOPClient *client = kapp->dcopClient();
                 QByteArray data;
                 QDataStream arg(data, IO_WriteOnly);
@@ -971,8 +975,13 @@ void CatalogManager::find()
                 arg << (_findOptions.ignoreContextInfo ? 1 : 0);
                 arg << (_findOptions.askForNextFile ? 1 : 0);
                 arg << (_findOptions.askForSave ? 1 : 0);
+		if(_configFile != "kbabelrc" ) {
+        	   arg << _configFile.utf8();
+                   funcCall="findInFile(QCString,QCString,QString,int,int,int,int,int,int,int,int,int,int,QCString)";
+                }
+		kdDebug(KBABEL) << "DCOP: " << QString(data.data()) << endl;
                 if( !client->send("kbabel","KBabelIFace",
-                                  "findInFile(QCString,QCString,QString,int,int,int,int,int,int,int,int,int,int)", data)
+                                  funcCall, data)
                     ) {
                     KMessageBox::error( this, i18n("DCOP communication with KBabel failed."), i18n("DCOP Communication Error"));
                     stopSearching();
@@ -1034,9 +1043,11 @@ void CatalogManager::replace()
         {
             if( startKBabel() )
             {
+		QCString funcCall("replaceInFile(QCString,QCString,QString,QString,int,int,int,int,int,int,int,int,int,int,int)");
                 DCOPClient *client = kapp->dcopClient();
                 QByteArray data;
                 QDataStream arg(data, IO_WriteOnly);
+                
                 arg << client->appId();
                 arg << url.utf8();
                 arg << options.findStr;
@@ -1052,8 +1063,12 @@ void CatalogManager::replace()
                 arg << (options.ask ? 1 : 0);
                 arg << (options.askForNextFile ? 1 : 0);
                 arg << (options.askForSave ? 1 : 0);
+		if(_configFile != "kbabelrc" ) {
+        	   arg << _configFile.utf8();
+                   funcCall="replaceInFile(QCString,QCString,QString,QString,int,int,int,int,int,int,int,int,int,int,int,QCString)";
+                }
                 if( !client->send("kbabel","KBabelIFace",
-                                  "replaceInFile(QCString,QCString,QString,QString,int,int,int,int,int,int,int,int,int,int,int)", data)
+                                  funcCall, data)
                     ) {
                     KMessageBox::error( this, i18n("DCOP communication with KBabel failed."), i18n("DCOP Communication Error"));
                     stopSearching();
@@ -1190,11 +1205,11 @@ void CatalogManager::projectNew()
 void CatalogManager::projectOpen()
 {
     QString oldproject = _project->filename();
-    if( oldproject == KBABEL_DEFAULTPROJECT )
+    if( oldproject == KBabel::ProjectManager::defaultProjectName() )
     {
         oldproject = QString();
     }
-    QString file = KFileDialog::getOpenFileName(oldproject, i18n("*|All Files"), this);
+    const QString file = KFileDialog::getOpenFileName(oldproject, QString::null, this);
     if (file.isEmpty())
     {
         return;
@@ -1213,6 +1228,7 @@ void CatalogManager::projectOpen()
 	updateSettings();
         changeProjectActions(file);
 	emit settingsChanged(_settings);
+
     }
     else
     {
@@ -1224,19 +1240,19 @@ void CatalogManager::projectClose()
 {
     disconnect( _project, SIGNAL (signalCatManSettingsChanged())
 	    , this, SLOT (updateSettings()));
-    _project = KBabel::ProjectManager::open(KBABEL_DEFAULTPROJECT);
+    _project = KBabel::ProjectManager::open(KBabel::ProjectManager::defaultProjectName());
     connect( _project, SIGNAL (signalCatManSettingsChanged())
 	    , this, SLOT (updateSettings()));
     _configFile = _project->filename();
     restoreSettings();
     updateSettings();
-    changeProjectActions(KBABEL_DEFAULTPROJECT);
+    changeProjectActions(KBabel::ProjectManager::defaultProjectName());
     emit settingsChanged(_settings);
 }
 
 void CatalogManager::changeProjectActions(const QString& project)
 {
-    bool def = project == KBABEL_DEFAULTPROJECT;
+    bool def = ( project == KBabel::ProjectManager::defaultProjectName() ) ;
 
     KAction* saveAction=(KAction*)actionCollection()->action( "project_close" );
     saveAction->setEnabled( ! def );
