@@ -1,10 +1,9 @@
 /* ****************************************************************************
   This file is part of KBabel
 
-  Copyright (C) 1999-2000 by Matthias Kiefer
-                            <matthias.kiefer@gmx.de>
-		2002-2003 by Stanislav Visnovsky
-			    <visnovsky@kde.org>
+  Copyright (C) 1999-2000 by Matthias Kiefer <matthias.kiefer@gmx.de>
+		2002-2003 by Stanislav Visnovsky <visnovsky@kde.org>
+  Copyright (C) 2006 by Nicolas GOUTTE <goutte@kde.org> 
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -77,15 +76,34 @@ public:
     * if the string ", fuzzy" is contained in the comment
     */
     bool isFuzzy() const;
+    
     /**
-    * returns true, if the translation in c-format, this means
-    * if the string ", c-format" is contained in the comment
-    */
+     * returns true, if the translation in c-format, this means
+     * if the string ", c-format" is contained in the comment
+     * @since 1.11.2 (KDE 3.5.2) not only "c-format" is supported but also
+     * "possible-c-format" (from the debug parameter of xgettext)
+     */
     bool isCformat() const;
+
     /**
-    * returns true, if the string ", no=c-format" is contained in the comment
+    * returns true, if the string ", no-c-format" is contained in the comment
     */
     bool isNoCformat() const;
+
+    /**
+     * returns true, if the translation in qt-format, this means
+     * if the string ", qt-format" is contained in the comment
+     * @since 1.11.2 (KDE 3.5.2)
+     */
+    bool isQtformat() const;
+
+    /**
+     * returns true, 
+     * if the string ", no-qt-format" is contained in the comment
+     * @since 1.11.2 (KDE 3.5.2)
+     */
+    bool isNoQtformat() const;
+
     /**
     * returns true, if the Msgid is untranslated, this means the
     * Msgstr is empty
