@@ -50,7 +50,7 @@
  *
  ***************************************************/
 
-K_EXPORT_COMPONENT_FACTORY( kbabel_xmltool, KGenericFactory<XMLTool> )
+K_EXPORT_COMPONENT_FACTORY( kbabel_xmltool, KGenericFactory<XMLTool> ( "kbabeldatatool" ) )
 
 using namespace KBabel;
 
