@@ -32,6 +32,7 @@
 #include <qptrvector.h>
 #include <qcolor.h>
 
+#include "subcost.h"
 #include "utils.h"
 
 class QFile;
@@ -47,10 +48,10 @@ class QFile;
  * Abstract, i.e. never instantiated cost items are
  * - TraceCost: Basic cost metrics (instr/read/write access + cache events)
  * - TraceCallCost: Additional call count cost metric.
- * - TraceCumulativeCost: Additional TraceCost aggregated.
+ * - TraceInclusiveCost: Additional TraceCost aggregated.
  * - TraceListCost: Adds dependency to a list of TraceCost's
  * - TraceCallListCost: same for list of TraceCallCost's
- * - TraceCumulativeListCost: same for list of TraceCumulativeCost's
+ * - TraceInclusiveListCost: same for list of TraceInclusiveCost's
  * - TraceCostItem: Base for cost items for "interesting" costs:
  *              TraceFunction, TraceClass, TraceFile, TraceObject
  *
@@ -121,6 +122,7 @@ class FixCost;
 class FixCallCost;
 class FixJump;
 class FixPool;
+class DynPool;
 class TopLevel;
 
 class TraceCost;
@@ -129,7 +131,7 @@ class TraceCostMapping;
 class TraceSubMapping;
 class TraceJumpCost;
 class TraceCallCost;
-class TraceCumulativeCost;
+class TraceInclusiveCost;
 
 class TracePartInstr;
 class TracePartInstrCall;
@@ -162,7 +164,7 @@ class TraceData;
 typedef QPtrList<TraceCost> TraceCostList;
 typedef QPtrList<TraceJumpCost> TraceJumpCostList;
 typedef QPtrList<TraceCallCost> TraceCallCostList;
-typedef QPtrList<TraceCumulativeCost> TraceCumulativeCostList;
+typedef QPtrList<TraceInclusiveCost> TraceInclusiveCostList;
 
 typedef QPtrList<TracePartCall>  TracePartCallList;
 typedef QPtrList<TracePartInstr> TracePartInstrList;
@@ -190,49 +192,6 @@ typedef QMap<QString, TraceFunction> TraceFunctionMap;
 typedef QMap<uint, TraceLine> TraceLineMap;
 
 
-typedef unsigned long long uint64;
-
-/**
- * Cost event counter, simple wrapper around a 64bit entity
- */
-class SubCost
-{
- public:
-    SubCost() {}
-    SubCost(uint64 i) { v=i; }
-    SubCost(unsigned i) { v=i; }
-    SubCost(int i) { v=(unsigned)i; }
-    SubCost(double d) { v= (uint64)(d + .5); }
-
-    SubCost& operator=(uint64 i) { v = i; return *this; }
-    SubCost& operator=(unsigned i) { v = i; return *this; }
-    SubCost& operator=(int i) { v = i; return *this; }
-    SubCost& operator=(double d) { v = (uint64)(d + .5); return *this; }
-
-    bool set(const char** s);
-    bool set(FixString& s) { return s.stripUInt64(v); }
-
-    operator uint64&() { return v; }
-
-    bool operator==(unsigned i) const { return v == i; }
-    bool operator==(int i) const { return v == (unsigned)i; }
-    bool operator<(unsigned i) const { return v < i; }
-    bool operator<(int i) const { return v < (unsigned)i; }
-    bool operator<(const SubCost& s) const { return v < s.v; }
-    bool operator>(unsigned i) const { return v > i; }
-    bool operator>(int i) const { return v > (unsigned)i; }
-    bool operator>(const SubCost& s) const { return v > s.v; }
-
-    /**
-     * Convert SubCost value into a QString,
-     * spaced every 3 digits.
-     */
-    QString pretty();
-
-    uint64 v;
-};
-
-
 /**
  * Addresses are 64bit values like costs to be able
  * to always load profile data produced on 64bit
@@ -260,6 +219,7 @@ class Addr
   bool operator>(const Addr& a) const { return _v > a._v; }
   bool operator>=(const Addr& a) const { return _v >= a._v; }
   bool operator<(const Addr& a) const { return _v < a._v; }
+  bool operator<=(const Addr& a) const { return _v <= a._v; }
 
   Addr operator+(int d) const { return Addr(_v + d); }
   Addr operator-(int d) const { return Addr(_v - d); }
@@ -272,7 +232,7 @@ typedef QMap<Addr, TraceInstr> TraceInstrMap;
 
 
 /**
- * An abstract item from a trace file.
+ * Base class for cost items.
  */
 class TraceItem
 {
@@ -358,15 +318,18 @@ public:
   TraceItem* dependant() { return _dep; }
 
   /**
-   * If this item is not derived, but from a single trace file
-   * set the trace file (=part) with this function.
-   * Call this function directly after the constructor.
+   * If this item is from a single profile data file, position
+   * points to a TracePart, otherwise to a TraceData object.
    */
-  void setPart(TracePart* p) { _part = p; }
+  void setPosition(TraceItem* p) { _position = p; }  
 
-  TracePart* part() const { return _part; }
+  // getters for specific positions, to be overwritten
+  virtual TracePart* part();
+  virtual const TracePart* part() const;
+  virtual TraceData* data();
+  virtual const TraceData* data() const;
 
-protected:
+ protected:
   /** Updates cost attributes.
    * This has to be called by subclasses that access cost attributes
    * directly
@@ -375,7 +338,7 @@ protected:
 
   bool _dirty;
 
-  TracePart* _part;
+  TraceItem* _position;
   TraceItem* _dep;
 
  private:
@@ -397,7 +360,7 @@ public:
    * The maximal number of subcosts a TraceCost can have.
    */
   static const int MaxRealIndex;
-#define MaxRealIndexValue 10
+#define MaxRealIndexValue 13
   static const int InvalidIndex;
 
 
@@ -415,10 +378,13 @@ public:
   // add a cost according to a submapping and a list of ASCII numbers
   void addCost(TraceSubMapping*, const char*);
   void addCost(TraceSubMapping*, FixString&);
-  void maxCost(TraceSubMapping*, FixString&);
   // add the cost of another item
   void addCost(TraceCost* item);
   void addCost(int index, SubCost value);
+
+  // maximal cost
+  void maxCost(TraceSubMapping*, FixString&);
+  void maxCost(TraceCost* item);
   void maxCost(int index, SubCost value);
   TraceCost diff(TraceCost* item);
 
@@ -435,11 +401,11 @@ public:
   SubCost subCost(int);
 
   /** Returns a cost attribute converted to a string
-   * (with space after 3 digits)
+   * (with space after every 3 digits)
    */
   QString prettySubCost(TraceCostType*);
 
-protected:
+ protected:
   virtual void update();
 
   SubCost _cost[MaxRealIndexValue];
@@ -656,7 +622,7 @@ class TraceJumpCost: public TraceItem
     void addFollowedCount(SubCost c) { _followedCount += c; }
     void addExecutedCount(SubCost c) { _executedCount += c; }
 
-protected:
+ protected:
     SubCost _executedCount, _followedCount;
 };
 
@@ -667,7 +633,7 @@ protected:
  */
 class TraceCallCost: public TraceCost
 {
-public:
+ public:
   TraceCallCost();
   virtual ~TraceCallCost();
 
@@ -680,30 +646,30 @@ public:
   QString prettyCallCount();
   void addCallCount(SubCost c);
 
-protected:
+ protected:
   SubCost _callCount;
 };
 
 
 /**
- * Cost item with additional cumulative metric
+ * Cost item with additional inclusive metric
  */
-class TraceCumulativeCost: public TraceCost
+class TraceInclusiveCost: public TraceCost
 {
-public:
-  TraceCumulativeCost();
-  virtual ~TraceCumulativeCost();
+ public:
+  TraceInclusiveCost();
+  virtual ~TraceInclusiveCost();
 
   // reimplementations for cost addition
   virtual QString costString(TraceCostMapping* m);
   virtual void clear();
 
   // additional cost metric
-  TraceCost* cumulative();
-  void addCumulative(TraceCost*);
+  TraceCost* inclusive();
+  void addInclusive(TraceCost*);
 
-protected:
-  TraceCost _cumulative;
+ protected:
+  TraceCost _inclusive;
 };
 
 
@@ -713,8 +679,8 @@ protected:
  */
 class TraceListCost: public TraceCost
 {
-public:
-  TraceListCost(bool onlyActiveParts = false);
+ public:
+  TraceListCost();
   virtual ~TraceListCost();
 
   // reimplementation for dependency list
@@ -722,13 +688,15 @@ public:
 
   TraceCostList& deps() { return _deps; }
   void addDep(TraceCost*);
-  TraceCost* findDep(TracePart*);
+  TraceCost* findDepFromPart(TracePart*);
+
+ protected:
+  // overwrite in subclass to change update behaviour
+  virtual bool onlyActiveParts() { return false; }
 
-protected:
   TraceCostList _deps;
-  bool _onlyActiveParts;
 
-private:
+ private:
   // very temporary: cached
   TraceCost* _lastDep;
 };
@@ -740,8 +708,8 @@ private:
  */
 class TraceJumpListCost: public TraceJumpCost
 {
-public:
-  TraceJumpListCost(bool onlyActiveParts = false);
+ public:
+  TraceJumpListCost();
   virtual ~TraceJumpListCost();
 
   // reimplementation for dependency list
@@ -749,14 +717,15 @@ public:
 
   TraceJumpCostList deps() { return _deps; }
   void addDep(TraceJumpCost*);
-  TraceJumpCost* findDep(TracePart*);
+  TraceJumpCost* findDepFromPart(TracePart*);
 
-protected:
+ protected:
+  // overwrite in subclass to change update behaviour
+  virtual bool onlyActiveParts() { return false; }
 
   TraceJumpCostList _deps;
-  bool _onlyActiveParts;
 
-private:
+ private:
   // very temporary: cached
   TraceJumpCost* _lastDep;
 };
@@ -770,8 +739,8 @@ private:
  */
 class TraceCallListCost: public TraceCallCost
 {
-public:
-  TraceCallListCost(bool onlyActiveParts = false);
+ public:
+  TraceCallListCost();
   virtual ~TraceCallListCost();
 
   // reimplementation for dependency list
@@ -779,42 +748,45 @@ public:
 
   TraceCallCostList deps() { return _deps; }
   void addDep(TraceCallCost*);
-  TraceCallCost* findDep(TracePart*);
+  TraceCallCost* findDepFromPart(TracePart*);
 
-protected:
+ protected:
+  // overwrite in subclass to change update behaviour
+  virtual bool onlyActiveParts() { return false; }
 
   TraceCallCostList _deps;
-  bool _onlyActiveParts;
 
-private:
+ private:
   // very temporary: cached
   TraceCallCost* _lastDep;
 };
 
 
 /**
- * Cumulative Cost Item dependend on a list of cumulative cost items.
+ * Inclusive Cost Item dependend on a list of inclusive cost items.
  */
-class TraceCumulativeListCost: public TraceCumulativeCost
+class TraceInclusiveListCost: public TraceInclusiveCost
 {
-public:
-  TraceCumulativeListCost(bool onlyActiveParts = false);
-  virtual ~TraceCumulativeListCost();
+ public:
+  TraceInclusiveListCost();
+  virtual ~TraceInclusiveListCost();
 
   // reimplementation for dependency
   virtual void update();
 
-  TraceCumulativeCostList deps() { return _deps; }
-  void addDep(TraceCumulativeCost*);
-  TraceCumulativeCost* findDep(TracePart*);
+  TraceInclusiveCostList deps() { return _deps; }
+  void addDep(TraceInclusiveCost*);
+  TraceInclusiveCost* findDepFromPart(TracePart*);
 
-protected:
-  TraceCumulativeCostList _deps;
-  bool _onlyActiveParts;
+ protected:
+  // overwrite in subclass to change update behaviour
+  virtual bool onlyActiveParts() { return false; }
 
-private:
+  TraceInclusiveCostList _deps;
+
+ private:
   // very temporary: cached
-  TraceCumulativeCost* _lastDep;
+  TraceInclusiveCost* _lastDep;
 };
 
 
@@ -832,13 +804,18 @@ private:
 class TracePartInstrJump: public TraceJumpCost
 {
  public:
-    TracePartInstrJump(TraceInstrJump*, TracePart*);
-    virtual ~TracePartInstrJump();
+  TracePartInstrJump(TraceInstrJump*, TracePartInstrJump*);
+  virtual ~TracePartInstrJump();
 
     virtual CostType type() const { return PartInstrJump; }
     // fix cost item
     virtual void update() {}
     TraceInstrJump* instrJump() const { return (TraceInstrJump*) _dep; }
+    TracePartInstrJump* next() const { return _next; }
+
+ private:
+    // chaining all parts for InstrJump
+    TracePartInstrJump* _next;
 };
 
 
@@ -849,7 +826,7 @@ class TracePartInstrJump: public TraceJumpCost
 class TracePartInstrCall: public TraceCallCost
 {
 public:
-  TracePartInstrCall(TraceInstrCall*, TracePart*);
+  TracePartInstrCall(TraceInstrCall*);
   virtual ~TracePartInstrCall();
 
   virtual CostType type() const { return PartInstrCall; }
@@ -866,7 +843,7 @@ public:
 class TracePartInstr: public TraceCost
 {
 public:
-  TracePartInstr(TraceInstr*, TracePart*);
+  TracePartInstr(TraceInstr*);
   virtual ~TracePartInstr();
 
   virtual CostType type() const { return PartInstr; }
@@ -883,7 +860,7 @@ public:
 class TracePartLineJump: public TraceJumpCost
 {
  public:
-    TracePartLineJump(TraceLineJump*, TracePart*);
+    TracePartLineJump(TraceLineJump*);
     virtual ~TracePartLineJump();
 
     virtual CostType type() const { return PartLineJump; }
@@ -900,7 +877,7 @@ class TracePartLineJump: public TraceJumpCost
 class TracePartLineCall: public TraceCallCost
 {
 public:
-  TracePartLineCall(TraceLineCall*, TracePart*);
+  TracePartLineCall(TraceLineCall*);
   virtual ~TracePartLineCall();
 
   virtual CostType type() const { return PartLineCall; }
@@ -918,7 +895,7 @@ public:
 class TracePartLine: public TraceCost
 {
 public:
-  TracePartLine(TraceLine*, TracePart*);
+  TracePartLine(TraceLine*);
   virtual ~TracePartLine();
 
   virtual CostType type() const { return PartLine; }
@@ -932,10 +909,10 @@ public:
 /**
  * Cost of a source region.
  */
-class TracePartLineRegion: public TraceCumulativeCost
+class TracePartLineRegion: public TraceInclusiveCost
 {
 public:
-  TracePartLineRegion(TraceLineRegion*, TracePart*);
+  TracePartLineRegion(TraceLineRegion*);
   virtual ~TracePartLineRegion();
 
   virtual CostType type() const { return PartLineRegion; }
@@ -952,7 +929,7 @@ public:
 class TracePartCall: public TraceCallListCost
 {
 public:
-  TracePartCall(TraceCall* call, TracePart* part);
+  TracePartCall(TraceCall* call);
   virtual ~TracePartCall();
 
   virtual CostType type() const { return PartCall; }
@@ -977,10 +954,10 @@ private:
  * Cost of a function,
  * from a single trace file.
  */
-class TracePartFunction: public TraceCumulativeCost
+class TracePartFunction: public TraceInclusiveCost
 {
 public:
-  TracePartFunction(TraceFunction*, TracePart*,
+  TracePartFunction(TraceFunction*,
 		    TracePartObject*, TracePartFile*);
   virtual ~TracePartFunction();
 
@@ -1042,10 +1019,10 @@ private:
  * Cost of a class,
  * from a single trace file.
  */
-class TracePartClass: public TraceCumulativeListCost
+class TracePartClass: public TraceInclusiveListCost
 {
 public:
-  TracePartClass(TraceClass*, TracePart*);
+  TracePartClass(TraceClass*);
   virtual ~TracePartClass();
 
   virtual CostType type() const { return PartClass; }
@@ -1060,10 +1037,10 @@ public:
  * Cost of a source file,
  * from a single trace file.
  */
-class TracePartFile: public TraceCumulativeListCost
+class TracePartFile: public TraceInclusiveListCost
 {
 public:
-  TracePartFile(TraceFile*, TracePart*);
+  TracePartFile(TraceFile*);
   virtual ~TracePartFile();
 
   virtual CostType type() const { return PartFile; }
@@ -1076,10 +1053,10 @@ public:
  * Cost of a object,
  * from a single trace file.
  */
-class TracePartObject: public TraceCumulativeListCost
+class TracePartObject: public TraceInclusiveListCost
 {
 public:
-  TracePartObject(TraceObject*, TracePart*);
+  TracePartObject(TraceObject*);
   virtual ~TracePartObject();
 
   virtual CostType type() const { return PartObject; }
@@ -1100,6 +1077,8 @@ public:
   virtual ~TracePart();
 
   virtual CostType type() const { return Part; }
+  virtual TracePart* part() { return this; }
+  virtual const TracePart* part() const { return this; }
 
   QString shortName() const;
   QString prettyName() const;
@@ -1119,8 +1098,6 @@ public:
   void setPartNumber(int n);
   void setThreadID(int t);
   void setProcessID(int p);
-  //const TraceCostList& items() const { return _items; }
-  TraceData* data() const { return _data; }
   TraceCost* totals() { return &_totals; }
   /* we get owner of the submapping */
   void setFixSubMapping(TraceSubMapping* sm) { _fixSubMapping = sm; }
@@ -1139,8 +1116,6 @@ private:
   QString _version;
 
   int _number, _tid, _pid;
-  //TraceCostList _items;
-  TraceData* _data;
 
   bool _active;
 
@@ -1154,9 +1129,9 @@ private:
 
 class TracePartList: public QPtrList<TracePart>
 {
-public:
+ public:
   QString names() const;
-protected:
+ protected:
   int compareItems ( Item item1, Item item2 );
 };
 
@@ -1170,7 +1145,7 @@ protected:
 /**
  * A jump from an instruction to another inside of a function
  */
-class TraceInstrJump: public TraceJumpListCost
+class TraceInstrJump: public TraceJumpCost
 {
 public:
     TraceInstrJump(TraceInstr* instrFrom, TraceInstr* instrTo,
@@ -1180,6 +1155,8 @@ public:
     virtual CostType type() const { return InstrJump; }
     virtual QString name() const;
 
+    virtual void update();
+
     TraceInstr* instrFrom() const { return _instrFrom; }
     TraceInstr* instrTo() const { return _instrTo; }
     bool isCondJump() const { return _isCondJump; }
@@ -1190,6 +1167,8 @@ public:
  private:
     TraceInstr *_instrFrom, *_instrTo;
     bool _isCondJump;
+    // list of parts for this InstrJump
+    TracePartInstrJump* _first;
 };
 
 class TraceInstrJumpList: public QPtrList<TraceInstrJump>
@@ -1198,7 +1177,7 @@ class TraceInstrJumpList: public QPtrList<TraceInstrJump>
     TraceInstrJumpList() { _sortLow = true; }
     void setSortLow(bool s) { _sortLow = s; }
 
-protected:
+ protected:
   int compareItems ( Item item1, Item item2 );
 
  private:
@@ -1211,7 +1190,7 @@ protected:
  */
 class TraceLineJump: public TraceJumpListCost
 {
-public:
+ public:
   TraceLineJump(TraceLine* lineFrom, TraceLine* lineTo,
 		bool isCondJump);
   virtual ~TraceLineJump();
@@ -1226,7 +1205,10 @@ public:
   // part factory
   TracePartLineJump* partLineJump(TracePart*);
 
-private:
+ protected:
+  bool onlyActiveParts() { return true; }
+
+ private:
   TraceLine *_lineFrom, *_lineTo;
   bool _isCondJump;
 };
@@ -1238,7 +1220,7 @@ class TraceLineJumpList: public QPtrList<TraceLineJump>
     TraceLineJumpList() { _sortLow = true; }
     void setSortLow(bool s) { _sortLow = s; }
 
-protected:
+ protected:
   int compareItems ( Item item1, Item item2 );
 
  private:
@@ -1251,7 +1233,7 @@ protected:
  */
 class TraceInstrCall: public TraceCallListCost
 {
-public:
+ public:
   TraceInstrCall(TraceCall* call, TraceInstr* instr);
   virtual ~TraceInstrCall();
 
@@ -1263,7 +1245,11 @@ public:
 
   // part factory
   TracePartInstrCall* partInstrCall(TracePart*, TracePartCall*);
-private:
+
+ protected:
+  bool onlyActiveParts() { return true; }
+
+ private:
   TraceInstr* _instr;
   TraceCall* _call;
 };
@@ -1274,7 +1260,7 @@ private:
  */
 class TraceLineCall: public TraceCallListCost
 {
-public:
+ public:
   TraceLineCall(TraceCall* call, TraceLine* line);
   virtual ~TraceLineCall();
 
@@ -1286,7 +1272,11 @@ public:
 
   // part factory
   TracePartLineCall* partLineCall(TracePart*, TracePartCall*);
-private:
+
+ protected:
+  bool onlyActiveParts() { return true; }
+
+ private:
   TraceLine* _line;
   TraceCall* _call;
 };
@@ -1298,7 +1288,7 @@ private:
  */
 class TraceCall: public TraceCallListCost
 {
-public:
+ public:
   TraceCall(TraceFunction* caller, TraceFunction* called);
   virtual ~TraceCall();
 
@@ -1331,7 +1321,10 @@ public:
   FixCallCost* setFirstFixCost(FixCallCost* fc)
     { FixCallCost* t = _firstFixCost; _firstFixCost = fc; return t; }
 
-private:
+ protected:
+  bool onlyActiveParts() { return true; }
+
+ private:
   TraceInstrCallList _instrCalls;
   TraceLineCallList _lineCalls;
   TraceFunction* _caller;
@@ -1348,7 +1341,7 @@ private:
  */
 class TraceInstr: public TraceListCost
 {
-public:
+ public:
   TraceInstr();
   virtual ~TraceInstr();
 
@@ -1377,12 +1370,14 @@ public:
   void setFunction(TraceFunction* f) { _function = f; }
   void setLine(TraceLine* l) { _line = l; }
 
-private:
+ protected:
+  bool onlyActiveParts() { return true; }
+
+ private:
   Addr _addr;
   TraceFunction* _function;
   TraceLine* _line;
 
-  TracePartInstrList _items;
   TraceInstrJumpList _instrJumps;
   TraceInstrCallList _instrCalls;
 };
@@ -1415,7 +1410,6 @@ public:
   bool hasCost(TraceCostType*);
   TraceFunctionSource* functionSource() const { return _sourceFile; }
   uint lineno() const { return _lineno; }
-  uint items() const { return _items.count(); }
   const TraceLineCallList& lineCalls() const { return _lineCalls; }
   const TraceLineJumpList& lineJumps() const { return _lineJumps; }
 
@@ -1423,11 +1417,13 @@ public:
   void setSourceFile(TraceFunctionSource* sf) { _sourceFile = sf; }
   void setLineno(uint lineno) { _lineno = lineno; }
 
-private:
+ protected:
+  bool onlyActiveParts() { return true; }
+
+ private:
   TraceFunctionSource* _sourceFile;
   uint _lineno;
 
-  TracePartLineList _items;
   TraceLineJumpList _lineJumps;
   TraceLineCallList _lineCalls;
 };
@@ -1436,22 +1432,21 @@ private:
 /*
  * Base class for all costs which
  * represent "interesting" items or group of items
- * with settable name and cumulative cost
+ * with settable name and inclusive cost
  */
-class TraceCostItem: public TraceCumulativeListCost
+class TraceCostItem: public TraceInclusiveListCost
 {
-public:
+ public:
   TraceCostItem();
   virtual ~TraceCostItem();
 
   virtual QString name() const { return _name; }
-  TraceData* data() const { return _data; }
-
-  void setData(TraceData* data) { _data = data; }
   virtual void setName(const QString& name) { _name = name; }
 
-protected:
-  TraceData* _data;
+ protected:
+  bool onlyActiveParts() { return true; }
+
+ protected:
   QString _name;
 };
 
@@ -1459,7 +1454,7 @@ protected:
 /**
  * Cost of a source region.
  */
-class TraceLineRegion: public TraceCumulativeListCost
+class TraceLineRegion: public TraceInclusiveListCost
 {
 public:
   TraceLineRegion(uint from, uint to, QString name);
@@ -1514,7 +1509,7 @@ public:
   TraceLineRegion* region(uint from, uint to, QString name,
 		      bool createNew = true);
 
-private:
+ private:
   TraceFile* _file;
   TraceFunction* _function;
   TraceLineMap* _lineMap;
@@ -1531,7 +1526,7 @@ private:
  */
 class TraceAssoziation
 {
-public:
+ public:
   /**
    * Creates an invalid assoziation.
    */
@@ -1569,12 +1564,13 @@ public:
    */
   static void invalidate(TraceData* data, int rtti);
 
-protected:
+ protected:
   TraceFunction* _function;
   bool _valid;
 };
 
 typedef QPtrList<TraceAssoziation> TraceAssoziationList;
+typedef QMap<TraceFunction*, TraceCall*> TraceCallMap;
 
 /**
  * A traced function
@@ -1585,7 +1581,7 @@ typedef QPtrList<TraceAssoziation> TraceAssoziationList;
  */
 class TraceFunction: public TraceCostItem
 {
-public:
+ public:
   TraceFunction();
   TraceFunction(TraceData* data, const QString& name,
                 TraceClass* cls, TraceFile* file, TraceObject* object);
@@ -1607,9 +1603,21 @@ public:
   TracePartFunction* partFunction(TracePart*,
                                   TracePartFile*, TracePartObject*);
 
+  /**
+   * Returns empty string if location is fully unknown.
+   * Use prettyLocation for single user-visible string.
+   * A function can have a lot of code from different sources (inlined);
+   * maxItems limits this list. Default is full list
+   */
+  QString location(int maxFiles = 0) const;
+
   QString prettyName() const;
-  QString location() const;
-  QString info() const; // prettyName + location
+  QString prettyLocation(int maxFiles = 0) const;
+  QString prettyNameWithLocation(int maxFiles = 1) const;
+  void addPrettyLocation(QString&, int maxFiles = 1) const;
+  // type + name + location
+  QString info() const; 
+
   TraceClass* cls() const { return _cls; }
   TraceFile* file() const { return _file; }
   TraceObject* object() const { return _object; }
@@ -1654,12 +1662,13 @@ public:
   void cycleReset();
   void cycleDFS(int d, int& pNo, TraceFunction** pTop);
 
-protected:
+ protected:
   TraceCallList _callers; // list of calls we are called from
   TraceCallList _callings; // list of calls we are calling (we are owner)
+  TraceCallMap _callingMap; // contains the same as _callings in a map
   TraceFunctionCycle* _cycle;
 
-private:
+ private:
   bool isUniquePrefix(QString) const;
   TraceFunctionMap::Iterator _myMapIterator;
 
@@ -1683,6 +1692,7 @@ private:
   int _calledContexts, _callingContexts;
 };
 
+typedef QMap<TraceFunction*,int> TraceFunctionSet;
 
 /**
  * A cycle of recursive calling functions.
@@ -1691,7 +1701,7 @@ private:
  */
 class TraceFunctionCycle: public TraceFunction
 {
-public:
+ public:
   TraceFunctionCycle(TraceFunction*, int n);
 
   virtual CostType type() const { return FunctionCycle; }
@@ -1706,11 +1716,12 @@ public:
   int cycleNo() const { return _cycleNo; }
   const TraceFunctionList& members() const { return _members; }
 
-private:
+ private:
   TraceFunction* _base;
   int _cycleNo;
 
   TraceFunctionList _members;
+  TraceFunctionSet _memberSet;
 };
 
 
@@ -1723,7 +1734,7 @@ private:
  */
 class TraceClass: public TraceCostItem
 {
-public:
+ public:
   TraceClass();
   virtual ~TraceClass();
 
@@ -1736,7 +1747,7 @@ public:
   // part factory
   TracePartClass* partClass(TracePart*);
 
-private:
+ private:
   TraceFunctionList _functions;
 };
 
@@ -1747,7 +1758,7 @@ private:
  */
 class TraceFile: public TraceCostItem
 {
-public:
+ public:
   TraceFile();
   virtual ~TraceFile();
 
@@ -1761,7 +1772,7 @@ public:
 
   // without path
   QString shortName() const;
-  QString prettyName() const { return shortName(); }
+  QString prettyName() const;
   QString prettyLongName() const;
   const TraceFunctionList& functions() const { return _functions; }
   const TraceFunctionSourceList& sourceFiles() const
@@ -1770,7 +1781,7 @@ public:
   // part factory
   TracePartFile* partFile(TracePart*);
 
-private:
+ private:
   TraceFunctionList _functions;
   TraceFunctionSourceList _sourceFiles;
   QString _dir;
@@ -1783,7 +1794,7 @@ private:
  */
 class TraceObject: public TraceCostItem
 {
-public:
+ public:
   TraceObject();
   virtual ~TraceObject();
 
@@ -1799,7 +1810,7 @@ public:
   // part factory
   TracePartObject* partObject(TracePart*);
 
-private:
+ private:
   TraceFunctionList _functions;
   QString _shortName;
 };
@@ -1813,12 +1824,14 @@ private:
  */
 class TraceData: public TraceCost
 {
-public:
+ public:
   TraceData(TopLevel* top = 0);
   TraceData(const QString& base);
   virtual ~TraceData();
 
   virtual CostType type() const { return Data; }
+  virtual TraceData* data() { return this; }
+  virtual const TraceData* data() const { return this; }
 
   /**
    * Loads a trace file.
@@ -1850,8 +1863,9 @@ public:
 
   TraceCostMapping* mapping() { return &_mapping; }
 
-  // memory pool for FixCost instances
+  // memory pools
   FixPool* fixPool();
+  DynPool* dynPool();
 
   // factories for object/file/class/function/line instances
   TraceObject* object(const QString& name);
@@ -1875,8 +1889,8 @@ public:
 
   // for pretty function names without signature if unique...
   TraceFunctionMap::Iterator functionIterator(TraceFunction*);
-  TraceFunctionMap::Iterator functionBeginIterator();
-  TraceFunctionMap::Iterator functionEndIterator();
+  TraceFunctionMap::ConstIterator functionBeginIterator() const;
+  TraceFunctionMap::ConstIterator functionEndIterator() const;
 
   TraceObjectMap& objectMap() { return _objectMap; }
   TraceFileMap& fileMap() { return _fileMap; }
@@ -1891,9 +1905,9 @@ public:
   QString command() const { return _command; }
   TraceCost* totals() { return &_totals; }
   void setMaxThreadID(int tid) { _maxThreadID = tid; }
-  int maxThreadID() { return _maxThreadID; }
+  int maxThreadID() const { return _maxThreadID; }
   void setMaxPartNumber(int n) { _maxPartNumber = n; }
-  int maxPartNumber() { return _maxPartNumber; }
+  int maxPartNumber() const { return _maxPartNumber; }
 
   // reset all manually set directories for source files
   void resetSourceDirs();
@@ -1910,7 +1924,7 @@ public:
   void updateFileCycles();
   bool inFunctionCycleUpdate() { return _inFunctionCycleUpdate; }
 
-private:
+ private:
   void init();
   // add trace part: events from one trace file
   TracePart* addPart(const QString& dir, const QString& file);
@@ -1924,6 +1938,7 @@ private:
   TraceCostMapping _mapping;
 
   FixPool* _fixPool;
+  DynPool* _dynPool;
 
   // always the trace totals (not dependent on active parts)
   TraceCost _totals;
@@ -1937,7 +1952,7 @@ private:
   QString _command;
   QString _traceName;
 
-  // Max of all costs of calls: This allows to see of the incl. cost can
+  // Max of all costs of calls: This allows to see if the incl. cost can
   // be hidden for a cost type, as it's always the same as self cost
   TraceCost _callMax;
 
