@@ -5,7 +5,7 @@
     source code is not replicated in the XMI file.
                              -------------------
     copyright            : (C) 2003 Brian Thomas brian.thomas@gsfc.nasa.gov
-      (C) 2004-2006  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
+      (C) 2004-2006  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>
 ***************************************************************************/
 
 /***************************************************************************
@@ -26,11 +26,14 @@
 // kde includes
 #include <kdebug.h>
 // app includes
+#include "codegen_utils.h"
 #include "../umldoc.h"
 #include "../classifier.h"
 #include "../operation.h"
 #include "../attribute.h"
 #include "../association.h"
+#include "../template.h"
+#include "../umltemplatelist.h"
 
 JavaWriter::JavaWriter() {
     startline = m_endl + m_indentation;
@@ -46,7 +49,7 @@ void JavaWriter::writeClass(UMLClassifier *c)
 {
 
     if (!c) {
-        kdDebug()<<"Cannot write class of NULL concept!\n";
+        kDebug()<<"Cannot write class of NULL concept!\n";
         return;
     }
 
@@ -63,7 +66,7 @@ void JavaWriter::writeClass(UMLClassifier *c)
 
     // check that we may open that file for writing
     QFile file;
-    if ( !openFile(file,fileName+".java") ) {
+    if ( !openFile(file, fileName) ) {
         emit codeGenerated(c, false);
         return;
     }
@@ -113,10 +116,12 @@ void JavaWriter::writeClass(UMLClassifier *c)
 
     // another preparation, determine what we have
     UMLAssociationList associations = c->getSpecificAssocs(Uml::at_Association); // BAD! only way to get "general" associations.
+    UMLAssociationList uniAssociations = c->getUniAssociationToBeImplemented();
+
     UMLAssociationList aggregations = c->getAggregations();
     UMLAssociationList compositions = c->getCompositions();
 
-    bool hasAssociations = aggregations.count() > 0 || associations.count() > 0 || compositions.count() > 0;
+    bool hasAssociations = aggregations.count() > 0 || associations.count() > 0 || compositions.count() > 0 || uniAssociations.count() > 0;
     bool hasAttributes = (atl.count() > 0);
     bool hasAccessorMethods = hasAttributes || hasAssociations;
     bool hasOperationMethods = (c->getOpList().count() > 0);
@@ -151,9 +156,9 @@ void JavaWriter::writeClass(UMLClassifier *c)
     }
 
     //only import classes in a different package as this class
-    UMLClassifierList imports;
+    UMLPackageList imports;
     findObjectsRelated(c,imports);
-    for (UMLClassifier *con = imports.first(); con; con = imports.next()) {
+    for (UMLPackage *con = imports.first(); con; con = imports.next()) {
         if (con->getBaseType() == Uml::ot_Datatype)
             continue;
         QString pkg = con->getPackage();
@@ -186,6 +191,7 @@ void JavaWriter::writeClass(UMLClassifier *c)
     writeAttributeDecls(atpub, atprot, atpriv, java);
 
     writeAssociationDecls(associations, c->getID(), java);
+    writeAssociationDecls(uniAssociations, c->getID(), java);
     writeAssociationDecls(aggregations, c->getID(), java);
     writeAssociationDecls(compositions, c->getID(), java);
 
@@ -230,6 +236,7 @@ void JavaWriter::writeClass(UMLClassifier *c)
 
     // first: determine the name of the other class
     writeAssociationMethods(associations, c, java);
+    writeAssociationMethods(uniAssociations, c, java);
     writeAssociationMethods(aggregations, c, java);
     writeAssociationMethods(compositions, c, java);
 
@@ -272,7 +279,7 @@ void JavaWriter::writeClassDecl(UMLClassifier *c, QTextStream &java)
     // Now write the actual class declaration
     QString scope = ""; // = scopeToJavaDecl(c->getVisibility());
     if (c->getVisibility() != Uml::Visibility::Public) {
-        // We should emit a warning in here .. java doesnt like to allow
+        // We should emit a warning in here .. java doesn't like to allow
         // private/protected classes. The best we can do (I believe)
         // is to let these declarations default to "package visibility"
         // which is a level between traditional "private" and "protected"
@@ -280,7 +287,7 @@ void JavaWriter::writeClassDecl(UMLClassifier *c, QTextStream &java)
     } else
         scope = "public ";
 
-    java<<(c->getAbstract()?QString("abstract "):QString(""))<<scope;
+    java<<((c->getAbstract() && !isInterface) ? QString("abstract ") : QString(""))<<scope;
     if(isInterface)
         java<<"interface ";
     else
@@ -288,20 +295,60 @@ void JavaWriter::writeClassDecl(UMLClassifier *c, QTextStream &java)
 
     java<<classname;
 
+    // Generics
+    UMLTemplateList template_params = c->getTemplateList();
+    if (template_params.count()) {
+        java << "<";
+        for (UMLTemplate *t = template_params.first(); t; ) {
+            QString formalName = t->getName();
+            java <<  formalName;
+            QString typeName = t->getTypeName();
+            if (typeName != "class") {
+                java << " extends " << typeName;
+            }
+            if ((t = template_params.next()) != NULL)
+                java << ", ";
+        }
+        java << ">" << m_endl;
+    }
 
     // write inheritances out
     UMLClassifier *concept;
-    UMLClassifierList superclasses = c->findSuperClassConcepts();
-
-    if(superclasses.count()>0)
-        java<<" extends ";
-
-    // Q: Where is 'implements' ??
+    UMLClassifierList superclasses = c->findSuperClassConcepts(UMLClassifier::CLASS);
 
     int i = 0;
     for (concept= superclasses.first(); concept; concept = superclasses.next())
     {
-        java<<cleanName(concept->getName())<<(i>0?", ":"");
+        if (i == 0)
+        {
+            java<< " extends ";
+        }
+        else
+        {
+            //The java generated code is wrong ! : No multiple inheritence of class
+            java<< ", " ;
+        }
+        java<< cleanName(concept->getName());
+        i++;
+    }
+
+    UMLClassifierList superInterfaces = c->findSuperClassConcepts(UMLClassifier::INTERFACE);
+    i = 0;
+    for (concept= superInterfaces.first(); concept; concept = superInterfaces.next())
+    {
+        if (i == 0)
+        {
+            if (isInterface)
+                java<< " extends ";
+            else
+                java<< " implements ";
+        }
+        else
+        {
+            //The java generated code is OK ! : multiple inheritence of interface
+            java<< ", " ;
+        }
+        java<< cleanName(concept->getName());
         i++;
     }
 
@@ -372,7 +419,8 @@ void JavaWriter::writeAttributeMethods(UMLAttributeList &atpub, Uml::Visibility
 
 }
 
-void JavaWriter::writeComment(QString comment, QString myIndent, QTextStream &java, bool javaDocStyle)
+void JavaWriter::writeComment(const QString &comment, const QString &myIndent,
+                              QTextStream &java, bool javaDocStyle)
 {
     // in the case we have several line comment..
     // NOTE: this part of the method has the problem of adopting UNIX newline,
@@ -395,7 +443,7 @@ void JavaWriter::writeComment(QString comment, QString myIndent, QTextStream &ja
             java << myIndent << " */" << m_endl;
     } else {
         // this should be more fancy in the future, breaking it up into 80 char
-        // lines so that it doesnt look too bad
+        // lines so that it doesn't look too bad
         writeBlankLine(java);
         if(javaDocStyle)
             java << myIndent << "/**" << m_endl << myIndent << " *";
@@ -481,10 +529,10 @@ void JavaWriter::writeAssociationRoleDecl(QString fieldClassName,
 
     // declare the association based on whether it is this a single variable
     // or a List (Vector). One day this will be done correctly with special
-    // multiplicity object that we dont have to figure out what it means via regex.
+    // multiplicity object that we don't have to figure out what it means via regex.
     if(multi.isEmpty() || multi.contains(QRegExp("^[01]$")))
     {
-        QString fieldVarName = roleName.replace(0, 1, roleName.left(1).lower());
+        QString fieldVarName = "m_" + roleName.replace(0, 1, roleName.left(1).lower());
         java<<startline<<scope<<" "<<fieldClassName<<" "<<fieldVarName<<";";
     }
     else
@@ -543,7 +591,7 @@ void JavaWriter::writeAssociationRoleMethod (QString fieldClassName, QString rol
 {
     if(multi.isEmpty() || multi.contains(QRegExp("^[01]$")))
     {
-        QString fieldVarName = "m_" + roleName.lower();
+        QString fieldVarName = "m_" + roleName.replace(0, 1, roleName.left(1).lower());
         writeSingleAttributeAccessorMethods(fieldClassName, fieldVarName, roleName,
                                             description, visib, change, false, java);
     }
@@ -562,7 +610,7 @@ void JavaWriter::writeVectorAttributeAccessorMethods (QString fieldClassName, QS
 {
 
     fieldClassName = fixTypeName(fieldClassName);
-    fieldName = capitaliseFirstLetter(fieldName);
+    fieldName = Codegen_Utils::capitalizeFirstLetter(fieldName);
     QString strVis = scopeToJavaDecl(visibility);
 
     // ONLY IF changeability is NOT Frozen
@@ -601,7 +649,7 @@ void JavaWriter::writeSingleAttributeAccessorMethods(QString fieldClassName, QSt
 
     QString strVis = scopeToJavaDecl(visibility);
     fieldClassName = fixTypeName(fieldClassName);
-    fieldName = capitaliseFirstLetter(fieldName);
+    fieldName = Codegen_Utils::capitalizeFirstLetter(fieldName);
 
     // set method
     if (change == Uml::chg_Changeable && !isFinal) {
@@ -640,12 +688,14 @@ void JavaWriter::writeConstructor(UMLClassifier *c, QTextStream &java)
 // IF the type is "string" we need to declare it as
 // the Java Object "String" (there is no string primative in Java).
 // Same thing again for "bool" to "boolean"
-QString JavaWriter::fixTypeName(QString string)
+QString JavaWriter::fixTypeName(const QString& string)
 {
     if (string.isEmpty())
         return "void";
-    string.replace(QRegExp("^string$"),"String");
-    string.replace(QRegExp("^bool$"),"boolean");
+    if (string == "string")
+        return "String";
+    if (string == "bool")
+        return "boolean";
     return string;
 }
 
@@ -663,6 +713,76 @@ QStringList JavaWriter::defaultDatatypes() {
     return l;
 }
 
+
+bool JavaWriter::compareJavaMethod(UMLOperation *op1, UMLOperation *op2)
+{
+    if (op1 == NULL || op2 == NULL)
+        return false;
+    if (op1 == op2)
+        return true;
+    if (op1->getName() != op2->getName())
+        return false;
+    UMLAttributeList atl1 = op1->getParmList();
+    UMLAttributeList atl2 = op2->getParmList();
+    if (atl1.count() != atl2.count())
+        return false;
+    UMLAttribute *at1;
+    UMLAttribute *at2;
+    for (at1  = atl1.first(), at2 = atl2.first(); at1 && at2 ; at1 = atl1.next(),at2 = atl2.next())
+    {
+        if (at1->getTypeName() != at2->getTypeName())
+            return false;
+    }
+    return true;
+
+}
+
+bool JavaWriter::javaMethodInList(UMLOperation *umlOp, UMLOperationList &opl)
+{
+    for (UMLOperation *op = opl.first(); op; op = opl.next()) {
+        if (JavaWriter::compareJavaMethod(op, umlOp)) {
+            return true;
+        }
+    }
+    return false;
+}
+
+void JavaWriter::getSuperImplementedOperations(UMLClassifier *c, UMLOperationList &yetImplementedOpList ,UMLOperationList &toBeImplementedOpList, bool noClassInPath)
+{
+    UMLClassifierList superClasses = c->findSuperClassConcepts();
+
+    for (UMLClassifier *concept= superClasses.first(); concept; concept = superClasses.next())
+    {
+        getSuperImplementedOperations(concept, yetImplementedOpList, toBeImplementedOpList, (concept->isInterface() && noClassInPath));
+        UMLOperationList opl = concept->getOpList();
+        for (UMLOperation *op = opl.first(); op; op = opl.next()) {
+            if (concept->isInterface() && noClassInPath) {
+                if (!JavaWriter::javaMethodInList(op,toBeImplementedOpList))
+                    toBeImplementedOpList.append(op);
+            }
+            else
+            {
+                if (!JavaWriter::javaMethodInList(op, yetImplementedOpList))
+                    yetImplementedOpList.append(op);
+            }
+        }
+    }
+
+}
+
+void JavaWriter::getInterfacesOperationsToBeImplemented(UMLClassifier *c, UMLOperationList &opList )
+{
+    UMLOperationList yetImplementedOpList;
+    UMLOperationList toBeImplementedOpList;
+
+    getSuperImplementedOperations(c,yetImplementedOpList, toBeImplementedOpList);
+    for (UMLOperation *op = toBeImplementedOpList.first(); op; op = toBeImplementedOpList.next())
+    {
+        if ( ! JavaWriter::javaMethodInList(op, yetImplementedOpList) && ! JavaWriter::javaMethodInList(op, opList) )
+            opList.append(op);
+    }
+}
+
 void JavaWriter::writeOperations(UMLClassifier *c, QTextStream &java) {
     UMLOperationList opl;
     UMLOperationList oppub,opprot,oppriv;
@@ -670,8 +790,11 @@ void JavaWriter::writeOperations(UMLClassifier *c, QTextStream &java) {
     opprot.setAutoDelete(false);
     oppriv.setAutoDelete(false);
 
-    //sort operations by scope first and see if there are abstrat methods
+    //sort operations by scope first and see if there are abstract methods
     opl = c->getOpList();
+    if (! c->isInterface()) {
+        getInterfacesOperationsToBeImplemented(c, opl);
+    }
     for (UMLOperation *op = opl.first(); op; op = opl.next()) {
         switch(op->getVisibility()) {
           case Uml::Visibility::Public:
@@ -720,7 +843,7 @@ void JavaWriter::writeOperations(UMLClassifier *c, QTextStream &java) {
 
 void JavaWriter::writeOperations(UMLOperationList &oplist, QTextStream &java) {
     UMLOperation *op;
-    UMLAttributeList *atl;
+    UMLAttributeList atl;
     UMLAttribute *at;
     int i,j;
     QString str;
@@ -737,23 +860,23 @@ void JavaWriter::writeOperations(UMLOperationList &oplist, QTextStream &java) {
             returnStr += "@return       "+methodReturnType+"\n";
 
         str = ""; // reset for next method
-        str += ((op->getAbstract() || isInterface) ? "abstract ":"");
-        str += (op->getStatic() ? "static":"");
-        str += scopeToJavaDecl(op->getVisibility()) + " ";
-        str += methodReturnType + " " +cleanName(op->getName()) + "( ";
+        str += ((op->getAbstract() && !isInterface) ? "abstract ":"");
+        str += scopeToJavaDecl(op->getVisibility()) + ' ';
+        str += (op->getStatic() ? "static ":"");
+        str += methodReturnType + ' ' +cleanName(op->getName()) + "( ";
 
         atl = op->getParmList();
-        i= atl->count();
+        i= atl.count();
         j=0;
-        for( at = atl->first(); at ;at = atl->next(),j++) {
+        for (at = atl.first(); at; at = atl.next(), j++) {
             QString typeName = fixTypeName(at->getTypeName());
             QString atName = cleanName(at->getName());
-            str += typeName + " " + atName +
+            str += typeName + ' ' + atName +
                    (!(at->getInitialValue().isEmpty()) ?
                     (QString(" = ")+at->getInitialValue()) :
                     QString(""))
                    + ((j < i-1)?", ":"");
-            returnStr += "@param        "+atName+" "+at->getDoc()+"\n";
+            returnStr += "@param        "+atName+' '+at->getDoc()+"\n";
         }
         str+= " )";
 
@@ -800,21 +923,12 @@ QString JavaWriter::scopeToJavaDecl(Uml::Visibility scope)
     return scopeString;
 }
 
-// methods like this _shouldnt_ be needed IF we properly did things thruought the code.
+// methods like this _shouldn't_ be needed IF we properly did things thruought the code.
 QString JavaWriter::getUMLObjectName(UMLObject *obj)
 {
     return(obj!=0)?obj->getName():QString("NULL");
 }
 
-QString JavaWriter::capitaliseFirstLetter(QString string)
-{
-    // we could lowercase everything tostart and then capitalize? Nah, it would
-    // screw up formatting like getMyRadicalVariable() to getMyradicalvariable(). Bah.
-    QChar firstChar = string.at(0);
-    string.replace( 0, 1, firstChar.upper());
-    return string;
-}
-
 void JavaWriter::writeBlankLine(QTextStream &java)
 {
     java<<m_endl;
