@@ -287,6 +287,7 @@ bool isCommonXMIAttribute( const QString &tag ) {
                    Uml::tagEq(tag, "isActive") ||
                    Uml::tagEq(tag, "namespace") ||
                    Uml::tagEq(tag, "ownerScope") ||
+                   Uml::tagEq(tag, "ModelElement.stereotype") ||
                    Uml::tagEq(tag, "GeneralizableElement.generalization") ||
                    Uml::tagEq(tag, "specialization") ||   //NYI
                    Uml::tagEq(tag, "clientDependency") || //NYI
@@ -572,6 +573,8 @@ QString progLangToString(Uml::Programming_Language pl) {
             return "C++";
         case Uml::pl_CSharp:
             return "C#";
+        case Uml::pl_D:
+            return "D";
         case Uml::pl_IDL:
             return "IDL";
         case Uml::pl_Java:
@@ -611,6 +614,8 @@ Uml::Programming_Language stringToProgLang(QString str) {
         return Uml::pl_Cpp;
     if (str == "C#")
         return Uml::pl_CSharp;
+    if (str == "D")
+        return Uml::pl_D;
     if (str == "IDL")
         return Uml::pl_IDL;
     if (str == "Java")
