@@ -27,7 +27,7 @@ class UMLObject;
 /**
  * This class is the non-graphical version of @ref UMLWidget.  These are
  * created and maintained in the class @ref UMLDoc.  This class holds all
- * the generic information needed for all UMLObjects.
+ * the generic information needed for all UML objects.
  *
  * @short The base class for UML objects.
  * @author Paul Hensgen <phensgen@techie.com>
@@ -60,7 +60,7 @@ public:
      * @param   name            The name of the object.
      * @param   id              The unique ID of the object.
      */
-    UMLObject(const QString &name = "" , Uml::IDType id = Uml::id_None);
+    explicit UMLObject(const QString &name = "" , Uml::IDType id = Uml::id_None);
 
     /**
      * Overloaded '==' operator
@@ -94,7 +94,7 @@ public:
     /**
      * Set the type of the object.
      *
-     * @param  The Uml::Object_Type to set.
+     * @param ot The Uml::Object_Type to set.
      */
     virtual void setBaseType(Uml::Object_Type ot);
 
@@ -131,7 +131,7 @@ public:
      *
      * @param s The visibility of the object.
      */
-    void setVisibility(Uml::Visibility s);
+    virtual void setVisibility(Uml::Visibility s);
 
     /**
      * Sets the classes stereotype name.
@@ -196,7 +196,7 @@ public:
      *                     Default: false.
      * @return  The UMLObject's enclosing package(s) as a text.
      */
-    QString getPackage(QString separator = QString::null,
+    QString getPackage(const QString& separator = QString::null,
                        bool includeRoot = false);
 
     /**
@@ -229,7 +229,7 @@ public:
     /**
      * Set the UMLObject's name
      */
-    void setName(const QString &strName);
+    virtual void setName(const QString &strName);
 
     /**
      * Returns the fully qualified name, i.e. all package prefixes and then m_Name.
@@ -242,7 +242,7 @@ public:
      *                     See UMLDoc::getRootFolder(). Default: false.
      * @return  The fully qualified name of this UMLObject.
      */
-    virtual QString getFullyQualifiedName(QString separator = QString::null,
+    virtual QString getFullyQualifiedName(const QString& separator = QString::null,
                                           bool includeRoot = false) const;
 
     /**
@@ -302,6 +302,14 @@ public:
      */
     virtual bool loadFromXMI( QDomElement & element );
 
+    /**
+     * Analyzes the given QDomElement for a reference to a stereotype.
+     *
+     * @param element    QDomElement to analyze.
+     * @return        True if a stereotype reference was found, else false.
+     */
+    bool loadStereotype(QDomElement & element);
+
     /**
      * Returns true if this UMLObject has classifier scope,
      * otherwise false (the default).
