@@ -1,8 +1,3 @@
-/*
- *  copyright (C) 2002-2004
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
- */
-
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -10,6 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   copyright (C) 2002-2006                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #ifndef USECASE_H
@@ -34,7 +31,7 @@ public:
      *  @param name             The name of the object.
      *  @param  id                              The id of the object.
      */
-    UMLUseCase(const QString & name = "", Uml::IDType id = Uml::id_None);
+    explicit UMLUseCase(const QString & name = "", Uml::IDType id = Uml::id_None);
 
     /**
      *  Standard deconstructor
