@@ -6,7 +6,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2006                                                    *
- *   Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                 *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #ifndef WIDGET_FACTORY_H
@@ -33,7 +33,8 @@ namespace Widget_Factory {
     /**
      * Create a UMLWidget according to the given XMI tag.
      */
-    UMLWidget* makeWidgetFromXMI(QString tag, QString idStr, UMLView *view);
+    UMLWidget* makeWidgetFromXMI(const QString& tag,
+                                 const QString& idStr, UMLView *view);
 
 }   // end namespace Widget_Factory
 
